@@ -29,6 +29,8 @@ from aiohttp_sqlalchemy.utils import (
 from aiohttp_sqlalchemy.views import (
     SAAbstractView,
     SABaseView,
+    SAInstanceMixin,
+    SAInstanceView,
     SAItemMixin,
     SAItemView,
     SAMixin,
@@ -37,13 +39,15 @@ from aiohttp_sqlalchemy.views import (
     SAView,
 )
 
-__version__ = '0.20.1'
+__version__ = '0.21.0'
 
 __all__ = [
     'SA_DEFAULT_KEY',
     'DuplicateAppKeyError',
     'DuplicateRequestKeyError',
     'SABaseView',
+    'SAInstanceMixin',
+    'SAInstanceView',
     'SAItemMixin',
     'SAItemView',
     'SAMixin',
