@@ -5,8 +5,8 @@ class AbstractDuplicateKeyError(ValueError):
 class DuplicateAppKeyError(AbstractDuplicateKeyError):
     def __init__(self, key: str):
         msg = (
-            f"Duplicated app key `{key}`. Check `bindings` argument "
-            f"in `aiohttp_sqlalchemy.setup()` call."
+            f'Duplicated app key `{key}`. Check `bindings` argument '
+            f'in `aiohttp_sqlalchemy.setup()` call.'
         )
         super().__init__(msg)
 
@@ -14,7 +14,7 @@ class DuplicateAppKeyError(AbstractDuplicateKeyError):
 class DuplicateRequestKeyError(AbstractDuplicateKeyError):
     def __init__(self, key: str):
         msg = (
-            f"Duplicated request key `{key}`. Check middlewares and "
-            f"decorators from `aiohttp_sqlalchemy`."
+            f'Duplicated request key `{key}`. Check middlewares and '
+            f'decorators from `aiohttp_sqlalchemy`.'
         )
         super().__init__(msg)
