@@ -2,7 +2,7 @@ from abc import ABCMeta
 from typing import Any, Optional
 
 from aiohttp.web import View
-from aiohttp_things.views import ContextMixin, PrimaryKeyMixin
+from aiohttp_things.views import ContextMixin, InstanceMixin, PrimaryKeyMixin
 from sqlalchemy.ext.asyncio import AsyncSession
 
 from aiohttp_sqlalchemy.constants import SA_DEFAULT_KEY
@@ -28,7 +28,12 @@ class SAModelMixin(SAMixin, metaclass=ABCMeta):
     sa_model: Any = None  # Not all developers use declarative mapping
 
 
-class SAItemMixin(PrimaryKeyMixin, SAModelMixin, metaclass=ABCMeta):
+class SAInstanceMixin(
+    InstanceMixin,
+    PrimaryKeyMixin,
+    SAModelMixin,
+    metaclass=ABCMeta,
+):
     """
     SQLAlchemy single instance class based view mixin.
 
@@ -45,11 +50,13 @@ class SAModelView(View, SAModelMixin):
     """SQLAlchemy single model class based view."""
 
 
-class SAItemView(View, SAItemMixin, metaclass=ABCMeta):
+class SAInstanceView(View, SAInstanceMixin, metaclass=ABCMeta):
     """SQLAlchemy single instance class based view."""
 
 
 # Synonyms
 SAAbstractView = SAMixin
+SAItemMixin = SAInstanceMixin
+SAItemView = SAInstanceView
 SAOneModelMixin = SAModelMixin
 SAView = SAModelView
